﻿using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using InfragisticsExampleWithListInsteadOfObservableCollection.Annotations;
using InfragisticsExampleWithListInsteadOfObservableCollection.Model;

namespace InfragisticsExampleWithListInsteadOfObservableCollection.ViewModel
{
    public class ClassViewModel : INotifyPropertyChanged
    {
        private ClassObject _class;

        public string Name
        {
            get => _class.Name;
            set
            {
                if (_class.Name == value) return;
                _class.Name = value;
                OnPropertyChanged(nameof(Name));
            }
        }
        public string Id
        {
            get => _class.Id;
            set
            {
                if (_class.Id == value) return;
                _class.Id = value;
                OnPropertyChanged(nameof(Id));
            }
        }

        public List<StudentObject> Students
        {
            get => _class.Students;
            set
            {
            }
        }

        public void AddStudent(StudentObject student)
        {
            if (Students == null)
                _class.Students = new List<StudentObject>();

            Students.Add(student);
            var students = _class.Students.ToList();

            _class.Students = students;

            OnPropertyChanged(nameof(Students));
        }

        public void RemoveStudent()
        {
            if (Students == null) 
                _class.Students = new List<StudentObject>();

            if(Students.Count > 1)
                Students.RemoveAt(Students.Count -1);

            var list = Students.ToList();
            _class.Students = list;
            OnPropertyChanged(nameof(Students));
        }

        public ClassViewModel(ClassObject classObject)
        {
            _class = classObject;
        }
        
        public event PropertyChangedEventHandler PropertyChanged;

        [NotifyPropertyChangedInvocator]
        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
